#include "lognormal.h"
#include <cmath>

LogNormalDistribution::LogNormalDistribution(const double tau, const double sigma, std::mt19937_64& rng) : Distribution(std::string("LogNormal"), tau, rng), m_sigma(sigma), m_distribution(std::log(tau), sigma) {}
LogNormalDistribution::LogNormalDistribution(std::mt19937_64& rng) : Distribution(std::string("LogNormal"), rng) {}

void LogNormalDistribution::setParameters(const std::unordered_map<std::string, double> &parameters) {
    m_sigma = parameters.at("sigma");
    Distribution::setParameters(parameters);
}

std::unordered_map<std::string, double> LogNormalDistribution::getParameters() const {
    auto parameter = Distribution::getParameters();
    parameter["sigma"] = m_sigma;
    return parameter;
}

void LogNormalDistribution::initialize() {
    m_distribution = std::lognormal_distribution(std::log(m_tau), m_sigma);
    m_tau_jump = m_distribution(m_rng);
}

void LogNormalDistribution::draw_tau() {
    m_tau_jump = m_distribution(m_rng);
}

std::string LogNormalDistribution::toString() const {
    return {"LogNormal/tau=" + std::to_string(m_tau) + "/sigma=" + std::to_string(m_sigma)};
}
